import json

# noinspection PyUnresolvedReferences,PyPackageRequirements
from browser import document, window, bind, ajax

CATEGORY_TYPE_PARAM = 'category-type'
CATEGORY_PARAM = 'category'


@bind(document['language-select'], 'change')
def on_language_change(event):
    selected_element = event.target
    window.location.href = selected_element.options[selected_element.selectedIndex].value


def on_element_click(event):
    target = event.target
    if 'element' not in target.classList:
        target = target.parent
    window.open(target.select('a')[0].href)


def select_matching_elements(category_type, category):
    def on_complete(response):
        title_element = document['selection-title']
        if response.status == 200 or response.status == 0:
            json_data = json.loads(response.responseText)
            if 'error' in json_data:
                title_element.text = json_data['error']
            else:
                title_element.innerHTML = f'{json_data["category-type"]} {json_data["category"]}'
        else:
            title_element.text = 'Connection/server error'

    params = {
        CATEGORY_TYPE_PARAM: category_type,
        CATEGORY_PARAM: category,
        'lang': document['language-code'].value,
    }
    ajax.get(document['details-url'].value, data=params, oncomplete=on_complete)
    for element in document.select('.element'):
        if not int(element.attrs['data-no-select']) and (key := f'data-{category_type}') in element.attrs:
            attribute_value = element.attrs[key]
            if attribute_value == category:
                element.classList.add('selected')
            else:
                element.classList.remove('selected')


def on_button_click(event):
    target = event.target
    select_matching_elements(category_type=target.attrs['data-type'], category=target.attrs['data-value'])


def prevent_follow_link(event):
    if not event.getModifierState('Control'):
        event.preventDefault()


def on_load():
    for button in document.select('.button'):
        if 'no-link' in button.classList:
            button.bind('click', prevent_follow_link)
        if 'select' in button.classList:
            button.bind('click', on_button_click)

    for element in document.select('.element'):
        element.bind('click', on_element_click)

    if CATEGORY_TYPE_PARAM in document.query and CATEGORY_PARAM in document.query:
        select_matching_elements(document.query[CATEGORY_TYPE_PARAM], document.query[CATEGORY_PARAM])


on_load()
